@@ -53,8 +53,9 @@ class Transcription(models.Model):
             return self.log_frequency
         count = self.pronouncedas_set.all().aggregate(count = Sum('word_form__frequency'))['count']
         totCount = WordForm.objects.all().aggregate(totcount = Sum('frequency'))['totcount']
-        freq = math.log((float(count) * 1000000)/float(totCount)+1,10)
-        self.log_frequency = freq
+        normed_freq = (float(count) * 1000000)/float(totCount)
+        log_freq = math.log(normed_freq+1,10)
+        self.log_frequency = log_freq
         self.save()
         return freq
 
